==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewaySslProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSL profile of an application gateway.
 * @property clientAuthConfiguration Client authentication configuration of the application gateway resource.
 * @property id Resource ID.
 * @property name Name of the SSL profile that is unique within an Application Gateway.
 * @property sslPolicy SSL policy of the application gateway resource.
 * @property trustedClientCertificates Array of references to application gateway trusted client certificates.
 */
public data class ApplicationGatewaySslProfileArgs(
    public val clientAuthConfiguration: Output<ApplicationGatewayClientAuthConfigurationArgs>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val sslPolicy: Output<ApplicationGatewaySslPolicyArgs>? = null,
    public val trustedClientCertificates: Output<List<SubResourceArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs.builder()
            .clientAuthConfiguration(
                clientAuthConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .sslPolicy(sslPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .trustedClientCertificates(
                trustedClientCertificates?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewaySslProfileArgs].
 */
@PulumiTagMarker
public class ApplicationGatewaySslProfileArgsBuilder internal constructor() {
    private var clientAuthConfiguration: Output<ApplicationGatewayClientAuthConfigurationArgs>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var sslPolicy: Output<ApplicationGatewaySslPolicyArgs>? = null

    private var trustedClientCertificates: Output<List<SubResourceArgs>>? = null

    /**
     * @param value Client authentication configuration of the application gateway resource.
     */
    @JvmName("bxlpgrbigybpevmi")
    public suspend
    fun clientAuthConfiguration(`value`: Output<ApplicationGatewayClientAuthConfigurationArgs>) {
        this.clientAuthConfiguration = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("epcyndpshlaiixvd")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the SSL profile that is unique within an Application Gateway.
     */
    @JvmName("pqudiveeeicbbbem")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value SSL policy of the application gateway resource.
     */
    @JvmName("iojrbchqkvsfdjvb")
    public suspend fun sslPolicy(`value`: Output<ApplicationGatewaySslPolicyArgs>) {
        this.sslPolicy = value
    }

    /**
     * @param value Array of references to application gateway trusted client certificates.
     */
    @JvmName("fosgyvofkcreejum")
    public suspend fun trustedClientCertificates(`value`: Output<List<SubResourceArgs>>) {
        this.trustedClientCertificates = value
    }

    @JvmName("twcrpuivxcdhqweq")
    public suspend fun trustedClientCertificates(vararg values: Output<SubResourceArgs>) {
        this.trustedClientCertificates = Output.all(values.asList())
    }

    /**
     * @param values Array of references to application gateway trusted client certificates.
     */
    @JvmName("ctwkoapvyglfptdw")
    public suspend fun trustedClientCertificates(values: List<Output<SubResourceArgs>>) {
        this.trustedClientCertificates = Output.all(values)
    }

    /**
     * @param value Client authentication configuration of the application gateway resource.
     */
    @JvmName("jlpssymetqlwsofd")
    public suspend
    fun clientAuthConfiguration(`value`: ApplicationGatewayClientAuthConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientAuthConfiguration = mapped
    }

    /**
     * @param argument Client authentication configuration of the application gateway resource.
     */
    @JvmName("qhqfpprucuyveyci")
    public suspend
    fun clientAuthConfiguration(argument: suspend ApplicationGatewayClientAuthConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewayClientAuthConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.clientAuthConfiguration = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("uhgbpfseoaafhrfy")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the SSL profile that is unique within an Application Gateway.
     */
    @JvmName("wjboxwubpcbgtcms")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SSL policy of the application gateway resource.
     */
    @JvmName("pvdmyywuuxjdptyg")
    public suspend fun sslPolicy(`value`: ApplicationGatewaySslPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslPolicy = mapped
    }

    /**
     * @param argument SSL policy of the application gateway resource.
     */
    @JvmName("pkucvwmeoekdebch")
    public suspend
    fun sslPolicy(argument: suspend ApplicationGatewaySslPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewaySslPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sslPolicy = mapped
    }

    /**
     * @param value Array of references to application gateway trusted client certificates.
     */
    @JvmName("ukefbojcgjhfpxbi")
    public suspend fun trustedClientCertificates(`value`: List<SubResourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedClientCertificates = mapped
    }

    /**
     * @param argument Array of references to application gateway trusted client certificates.
     */
    @JvmName("hksjjyqsycqvknqu")
    public suspend
    fun trustedClientCertificates(argument: List<suspend SubResourceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SubResourceArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.trustedClientCertificates = mapped
    }

    /**
     * @param argument Array of references to application gateway trusted client certificates.
     */
    @JvmName("esjhhedemqoahxbt")
    public suspend fun trustedClientCertificates(
        vararg
        argument: suspend SubResourceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map { SubResourceArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.trustedClientCertificates = mapped
    }

    /**
     * @param argument Array of references to application gateway trusted client certificates.
     */
    @JvmName("vqbumeitdxopnshy")
    public suspend
    fun trustedClientCertificates(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SubResourceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.trustedClientCertificates = mapped
    }

    /**
     * @param values Array of references to application gateway trusted client certificates.
     */
    @JvmName("akjhxqjblujacfjy")
    public suspend fun trustedClientCertificates(vararg values: SubResourceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trustedClientCertificates = mapped
    }

    internal fun build(): ApplicationGatewaySslProfileArgs = ApplicationGatewaySslProfileArgs(
        clientAuthConfiguration = clientAuthConfiguration,
        id = id,
        name = name,
        sslPolicy = sslPolicy,
        trustedClientCertificates = trustedClientCertificates,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewaySslProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSL profile of an application gateway.
 * @property clientAuthConfiguration Client authentication configuration of the application gateway resource.
 * @property id Resource ID.
 * @property name Name of the SSL profile that is unique within an Application Gateway.
 * @property sslPolicy SSL policy of the application gateway resource.
 * @property trustedClientCertificates Array of references to application gateway trusted client certificates.
 */
public data class ApplicationGatewaySslProfileArgs(
    public val clientAuthConfiguration: Output<ApplicationGatewayClientAuthConfigurationArgs>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val sslPolicy: Output<ApplicationGatewaySslPolicyArgs>? = null,
    public val trustedClientCertificates: Output<List<SubResourceArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewaySslProfileArgs.builder()
            .clientAuthConfiguration(
                clientAuthConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .sslPolicy(sslPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .trustedClientCertificates(
                trustedClientCertificates?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewaySslProfileArgs].
 */
@PulumiTagMarker
public class ApplicationGatewaySslProfileArgsBuilder internal constructor() {
    private var clientAuthConfiguration: Output<ApplicationGatewayClientAuthConfigurationArgs>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var sslPolicy: Output<ApplicationGatewaySslPolicyArgs>? = null

    private var trustedClientCertificates: Output<List<SubResourceArgs>>? = null

    /**
     * @param value Client authentication configuration of the application gateway resource.
     */
    @JvmName("iqhmtclcoohrhsrm")
    public suspend
    fun clientAuthConfiguration(`value`: Output<ApplicationGatewayClientAuthConfigurationArgs>) {
        this.clientAuthConfiguration = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("mnxpaqyfeqenkonn")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the SSL profile that is unique within an Application Gateway.
     */
    @JvmName("wrdktbymexmewrxp")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value SSL policy of the application gateway resource.
     */
    @JvmName("cheupkadjyomytwj")
    public suspend fun sslPolicy(`value`: Output<ApplicationGatewaySslPolicyArgs>) {
        this.sslPolicy = value
    }

    /**
     * @param value Array of references to application gateway trusted client certificates.
     */
    @JvmName("kkadbhjsasvshjkr")
    public suspend fun trustedClientCertificates(`value`: Output<List<SubResourceArgs>>) {
        this.trustedClientCertificates = value
    }

    @JvmName("eoffgvengwcgnijw")
    public suspend fun trustedClientCertificates(vararg values: Output<SubResourceArgs>) {
        this.trustedClientCertificates = Output.all(values.asList())
    }

    /**
     * @param values Array of references to application gateway trusted client certificates.
     */
    @JvmName("wrjkkytpuwutwnus")
    public suspend fun trustedClientCertificates(values: List<Output<SubResourceArgs>>) {
        this.trustedClientCertificates = Output.all(values)
    }

    /**
     * @param value Client authentication configuration of the application gateway resource.
     */
    @JvmName("qlhrlweqeifpvvtq")
    public suspend
    fun clientAuthConfiguration(`value`: ApplicationGatewayClientAuthConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientAuthConfiguration = mapped
    }

    /**
     * @param argument Client authentication configuration of the application gateway resource.
     */
    @JvmName("vaaiixfweqvymjda")
    public suspend
    fun clientAuthConfiguration(argument: suspend ApplicationGatewayClientAuthConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewayClientAuthConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.clientAuthConfiguration = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("mosyfjelyjockdar")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the SSL profile that is unique within an Application Gateway.
     */
    @JvmName("jofpyaandhbmyhiu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SSL policy of the application gateway resource.
     */
    @JvmName("guimmwbqoqtgvqgs")
    public suspend fun sslPolicy(`value`: ApplicationGatewaySslPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslPolicy = mapped
    }

    /**
     * @param argument SSL policy of the application gateway resource.
     */
    @JvmName("oocqfdrqgaojofji")
    public suspend
    fun sslPolicy(argument: suspend ApplicationGatewaySslPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewaySslPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sslPolicy = mapped
    }

    /**
     * @param value Array of references to application gateway trusted client certificates.
     */
    @JvmName("ueokwjorbwxguqda")
    public suspend fun trustedClientCertificates(`value`: List<SubResourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedClientCertificates = mapped
    }

    /**
     * @param argument Array of references to application gateway trusted client certificates.
     */
    @JvmName("rlcufjqkwerulyhq")
    public suspend
    fun trustedClientCertificates(argument: List<suspend SubResourceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SubResourceArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.trustedClientCertificates = mapped
    }

    /**
     * @param argument Array of references to application gateway trusted client certificates.
     */
    @JvmName("pfececkdhlaimimy")
    public suspend fun trustedClientCertificates(
        vararg
        argument: suspend SubResourceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map { SubResourceArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.trustedClientCertificates = mapped
    }

    /**
     * @param argument Array of references to application gateway trusted client certificates.
     */
    @JvmName("rpqcdtgjnqymamtg")
    public suspend
    fun trustedClientCertificates(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SubResourceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.trustedClientCertificates = mapped
    }

    /**
     * @param values Array of references to application gateway trusted client certificates.
     */
    @JvmName("cfhfouovimdttuwl")
    public suspend fun trustedClientCertificates(vararg values: SubResourceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trustedClientCertificates = mapped
    }

    internal fun build(): ApplicationGatewaySslProfileArgs = ApplicationGatewaySslProfileArgs(
        clientAuthConfiguration = clientAuthConfiguration,
        id = id,
        name = name,
        sslPolicy = sslPolicy,
        trustedClientCertificates = trustedClientCertificates,
    )
}
